==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/pl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendarz",
    "Individual" : "Indywidualny",
    "Group" : "Grupa",
    "Resource" : "Źródło",
    "Room" : "Pokój",
    "Unknown" : "Nieznany",
    "Required" : "Wymagany",
    "Optional" : "Opcjonalny",
    "Does not attend" : "Nie uczestniczy",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracanie do UTC",
    "Please create a calendar first." : "Proszę najpierw stworzyć kalendarz.",
    "New event" : "Nowe zdarzenie",
    "Attendees" : "Uczestnicy",
    "Reminders" : "Przypomnienia",
    "Repeating" : "Powtarzające się",
    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
    "Please add a title!" : "Proszę dodać tytuł!",
    "Please select a calendar!" : "Proszę wybrać kalendarz!",
    "None" : "Brak.",
    "Every day" : "Codziennie",
    "Every week" : "Co tydzień",
    "Every month" : "Co miesiąc",
    "Every year" : "Co roku",
    "never" : "nigdy",
    "after" : "po",
    "At time of event" : "W momencie zdarzenia",
    "5 minutes before" : "5 minut przed",
    "10 minutes before" : "10 minut przed",
    "15 minutes before" : "15 minut przed",
    "30 minutes before" : "30 minut przed",
    "1 hour before" : "1 godzinę przed",
    "2 hours before" : "2 godziny przed",
    "Custom" : "Dowolnie",
    "Audio" : "Dźwięk",
    "E Mail" : "e-mail",
    "sec" : "sek",
    "min" : "min",
    "hours" : "godzin",
    "days" : "dniach",
    "week" : "tydzień",
    "before" : "przed",
    "start" : "rozpocznij",
    "end" : "zakończ",
    "Week {number} of {year}" : "{number}. tydzień {year}",
    "Successfully imported" : "Import zakończył się pomyślnie",
    "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
    "Partially imported, {n} failures" : "Import wykonany częściowo, {n} błędy/błędów",
    "Audio alarm" : "Alarm dźwiękowy",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem zdarzenia",
    "{type} {time} before the event ends" : "{type} {time} przed zakończeniem zdarzenia",
    "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu zdarzenia",
    "{type} {time} after the event ends" : "{type} {time} po zakończeniu zdarzenia",
    "{type} at the event's start" : "{type} na początku wydarzenia",
    "{type} at the event's end" : "{type} na końcu wydarzenia",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Title of the Event" : "Nazwa wydarzenia",
    "starts" : "rozpoczyna się",
    "ends" : "kończy się",
    "All day Event" : "Wydarzenie całodniowe",
    "Location" : "Lokalizacja",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "More ..." : "Więcej...",
    "Create" : "Utwórz",
    "Update" : "Aktualizuj",
    "Close" : "Zamknij",
    "Description" : "Opis",
    "Export" : "Eksportuj",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Skontaktuj się z administratorem i poproś o wyłączenie opcji \"asset-pipeline.enabled\"  w konfiguracji.",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Today" : "Dziś",
    "Share Calendar" : "Współdziel kalendarz",
    "More" : "Więcej",
    "Edit" : "Edytuj",
    "group" : "grupa",
    "New Calendar" : "Nowy kalendarz",
    "Subscriptions" : "Subskrypcje",
    "New Subscription" : "Nowa Subskrypcja",
    "Url" : "Url",
    "Edit event" : "Edytuj zdarzenie",
    "Delete Event" : "Usuń zdarzenie",
    "Save Event" : "Zapisz zdarzenie",
    "Time" : "Czas",
    "Type" : "Typ",
    "Repeat" : "Powtarzaj",
    "Add" : "Dodaj",
    "E-Mail address of attendee" : "Adres e-mail uczestnika",
    "Please add your email address in the personal settings in order to add attendees." : "Aby móc dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
    "from" : "z",
    "to" : "do",
    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
    "Repeat every ..." : "Powtarzaj każdą...",
    "end repeat ..." : "zakończ powtarzanie ...",
    "Import Calendars" : "Importuj Kalendarze",
    "Import canceled" : "Import anulowany",
    "Analyzing calendar" : "Analiza kalendarza",
    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
    "New calendar" : "Nowy kalendarz",
    "Import scheduled" : "Import został zaplanowany",
    "Settings" : "Ustawienia",
    "Import calendar" : "Importuj kalendarz",
    "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
    "Primary CalDAV address" : "Podstawowy adres CalDAV",
    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/pl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendarz",
    "Individual" : "Indywidualny",
    "Group" : "Grupa",
    "Resource" : "Źródło",
    "Room" : "Pokój",
    "Unknown" : "Nieznany",
    "Required" : "Wymagany",
    "Optional" : "Opcjonalny",
    "Does not attend" : "Nie uczestniczy",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracanie do UTC",
    "Please create a calendar first." : "Proszę najpierw stworzyć kalendarz.",
    "New event" : "Nowe zdarzenie",
    "Attendees" : "Uczestnicy",
    "Reminders" : "Przypomnienia",
    "Repeating" : "Powtarzające się",
    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
    "Please add a title!" : "Proszę dodać tytuł!",
    "Please select a calendar!" : "Proszę wybrać kalendarz!",
    "Global" : "Ogólny",
    "None" : "Brak.",
    "Every day" : "Codziennie",
    "Every week" : "Co tydzień",
    "Every month" : "Co miesiąc",
    "Every year" : "Co roku",
    "never" : "nigdy",
    "after" : "po",
    "At time of event" : "W momencie zdarzenia",
    "5 minutes before" : "5 minut przed",
    "10 minutes before" : "10 minut przed",
    "15 minutes before" : "15 minut przed",
    "30 minutes before" : "30 minut przed",
    "1 hour before" : "1 godzinę przed",
    "2 hours before" : "2 godziny przed",
    "Custom" : "Dowolnie",
    "Audio" : "Dźwięk",
    "E Mail" : "e-mail",
    "sec" : "sek",
    "min" : "min",
    "hours" : "godzin",
    "days" : "dniach",
    "week" : "tydzień",
    "before" : "przed",
    "start" : "rozpocznij",
    "end" : "zakończ",
    "Editing reminders of uknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
    "Week {number} of {year}" : "{number}. tydzień {year}",
    "Successfully imported" : "Import zakończył się pomyślnie",
    "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
    "Partially imported, {n} failures" : "Import wykonany częściowo, {n} błędy/błędów",
    "Audio alarm" : "Alarm dźwiękowy",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem zdarzenia",
    "{type} {time} before the event ends" : "{type} {time} przed zakończeniem zdarzenia",
    "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu zdarzenia",
    "{type} {time} after the event ends" : "{type} {time} po zakończeniu zdarzenia",
    "{type} at the event's start" : "{type} na początku wydarzenia",
    "{type} at the event's end" : "{type} na końcu wydarzenia",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Title of the Event" : "Nazwa wydarzenia",
    "starts" : "rozpoczyna się",
    "ends" : "kończy się",
    "All day Event" : "Wydarzenie całodniowe",
    "Location" : "Lokalizacja",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "More ..." : "Więcej...",
    "Create" : "Utwórz",
    "Update" : "Aktualizuj",
    "Close" : "Zamknij",
    "Description" : "Opis",
    "Export" : "Eksportuj",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Skontaktuj się z administratorem i poproś o wyłączenie opcji \"asset-pipeline.enabled\"  w konfiguracji.",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Today" : "Dziś",
    "Share Calendar" : "Współdziel kalendarz",
    "More" : "Więcej",
    "Edit" : "Edytuj",
    "group" : "grupa",
    "New Calendar" : "Nowy kalendarz",
    "Subscriptions" : "Subskrypcje",
    "New Subscription" : "Nowa Subskrypcja",
    "Url" : "Url",
    "Edit event" : "Edytuj zdarzenie",
    "Delete Event" : "Usuń zdarzenie",
    "Save Event" : "Zapisz zdarzenie",
    "Time" : "Czas",
    "Type" : "Typ",
    "Relative" : "Pokrewny",
    "Absolute" : "Całkowity",
    "Repeat" : "Powtarzaj",
    "Add" : "Dodaj",
    "E-Mail address of attendee" : "Adres e-mail uczestnika",
    "Please add your email address in the personal settings in order to add attendees." : "Aby móc dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
    "from" : "z",
    "to" : "do",
    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
    "Repeat every ..." : "Powtarzaj każdą...",
    "end repeat ..." : "zakończ powtarzanie ...",
    "Import Calendars" : "Importuj Kalendarze",
    "Import canceled" : "Import anulowany",
    "Analyzing calendar" : "Analiza kalendarza",
    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
    "New calendar" : "Nowy kalendarz",
    "Import scheduled" : "Import został zaplanowany",
    "Settings" : "Ustawienia",
    "Import calendar" : "Importuj kalendarz",
    "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
    "Primary CalDAV address" : "Podstawowy adres CalDAV",
    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
